@@ -36,6 +36,7 @@
 #include "data/model/TextModel.h"
 #include "data/model/ImageModel.h"
 #include "data/model/AlignmentModel.h"
+#include "data/model/AggregateWaveModel.h"
 
 #include "transform/TransformFactory.h"
 
@@ -57,13 +58,13 @@ SVFileReader::SVFileReader(Document *document,
     m_document(document),
     m_paneCallback(callback),
     m_location(location),
-    m_currentPane(0),
-    m_currentLayer(0),
-    m_currentDataset(0),
-    m_currentDerivedModel(0),
+    m_currentPane(nullptr),
+    m_currentLayer(nullptr),
+    m_currentDataset(nullptr),
+    m_currentDerivedModel(nullptr),
     m_currentDerivedModelId(-1),
-    m_currentPlayParameters(0),
-    m_currentTransformSource(0),
+    m_currentPlayParameters(nullptr),
+    m_currentTransformSource(nullptr),
     m_currentTransformChannel(0),
     m_currentTransformIsNewStyle(true),
     m_datasetSeparator(" "),
@@ -209,6 +210,7 @@ SVFileReader::startElement(const QString &, const QString &,
 
     } else if (name == "derivation") {
 
+        makeAggregateModels(); // must be done before derivations that use them
         ok = readDerivation(attributes);
 
     } else if (name == "playparameters") {
@@ -295,7 +297,7 @@ SVFileReader::endElement(const QString &, const QString &,
             }
         }
 
-        m_currentDataset = 0;
+        m_currentDataset = nullptr;
 
     } else if (name == "data") {
 
@@ -339,9 +341,9 @@ SVFileReader::endElement(const QString &, const QString &,
         }
 
         m_addedModels.insert(m_currentDerivedModel);
-        m_currentDerivedModel = 0;
+        m_currentDerivedModel = nullptr;
         m_currentDerivedModelId = -1;
-        m_currentTransformSource = 0;
+        m_currentTransformSource = nullptr;
         m_currentTransform = Transform();
         m_currentTransformChannel = -1;
 
@@ -354,7 +356,7 @@ SVFileReader::endElement(const QString &, const QString &,
     } else if (name == "selections") {
         m_inSelections = false;
     } else if (name == "playparameters") {
-        m_currentPlayParameters = 0;
+        m_currentPlayParameters = nullptr;
     }
 
     return true;
@@ -402,9 +404,61 @@ SVFileReader::readWindow(const QXmlAttributes &)
     return true;
 }
 
+void
+SVFileReader::makeAggregateModels()
+{
+    std::map<int, PendingAggregateRec> stillPending;
+    
+    for (auto p: m_pendingAggregates) {
+
+        int id = p.first;
+        const PendingAggregateRec &rec = p.second;
+        bool skip = false;
+
+        AggregateWaveModel::ChannelSpecList specs;
+        for (int componentId: rec.components) {
+            bool found = false;
+            if (m_models.find(componentId) != m_models.end()) {
+                RangeSummarisableTimeValueModel *rs =
+                    dynamic_cast<RangeSummarisableTimeValueModel *>
+                    (m_models[componentId]);
+                if (rs) {
+                    specs.push_back(AggregateWaveModel::ModelChannelSpec
+                                    (rs, -1));
+                    found = true;
+                }
+            }
+            if (!found) {
+                SVDEBUG << "SVFileReader::makeAggregateModels:"
+                        << "Unknown component model id "
+                        << componentId << " in aggregate model id " << id
+                        << ", hoping we won't be needing it just yet"
+                        << endl;
+                skip = true;
+            }                
+        }
+
+        if (skip) {
+            stillPending[id] = rec;
+        } else {
+            AggregateWaveModel *model = new AggregateWaveModel(specs);
+            model->setObjectName(rec.name);
+
+            SVDEBUG << "SVFileReader::makeAggregateModels: created aggregate model id "
+                    << id << " with " << specs.size() << " components" << endl;
+        
+            m_models[id] = model;
+        }
+    }
+
+    m_pendingAggregates = stillPending;
+}
+
 void
 SVFileReader::addUnaddedModels()
 {
+    makeAggregateModels();
+    
     std::set<Model *> unaddedModels;
     
     for (std::map<int, Model *>::iterator i = m_models.begin();
@@ -455,7 +509,7 @@ SVFileReader::readModel(const QXmlAttributes &attributes)
 
     if (type == "wavefile") {
         
-        WaveFileModel *model = 0;
+        WaveFileModel *model = nullptr;
         FileFinder *ff = FileFinder::getInstance();
         QString originalPath = attributes.value("file");
         QString path = ff->find(FileFinder::AudioFile,
@@ -490,7 +544,7 @@ SVFileReader::readModel(const QXmlAttributes &attributes)
             model = new ReadOnlyWaveFileModel(file, rate);
             if (!model->isOK()) {
                 delete model;
-                model = 0;
+                model = nullptr;
             }
         }
 
@@ -510,6 +564,30 @@ SVFileReader::readModel(const QXmlAttributes &attributes)
 
         return true;
 
+    } else if (type == "aggregatewave") {
+
+        QString components = attributes.value("components");
+        QStringList componentIdStrings = components.split(",");
+        std::vector<int> componentIds;
+        for (auto cid: componentIdStrings) {
+            bool ok = false;
+            int id = cid.toInt(&ok);
+            if (!ok) {
+                SVCERR << "SVFileReader::readModel: Failed to convert component model id from part \"" << cid << "\" in \"" << components << "\"" << endl;
+            } else {
+                componentIds.push_back(id);
+            }
+        }
+        PendingAggregateRec rec { name, sampleRate, componentIds };
+        m_pendingAggregates[id] = rec;
+
+        // The aggregate model will be constructed from its pending
+        // record in makeAggregateModels; it can't happen here because
+        // the component models might not all have been observed yet
+        // (an unfortunate accident of the way the file is written)
+
+        return true;
+
     } else if (type == "dense") {
         
         READ_MANDATORY(int, dimensions, toInt);
@@ -682,7 +760,7 @@ SVFileReader::readModel(const QXmlAttributes &attributes)
         READ_MANDATORY(int, aligned, toInt);
         READ_MANDATORY(int, path, toInt);
 
-        Model *refModel = 0, *alignedModel = 0, *pathModel = 0;
+        Model *refModel = nullptr, *alignedModel = nullptr, *pathModel = nullptr;
 
         if (m_models.find(reference) != m_models.end()) {
             refModel = m_models[reference];
@@ -710,7 +788,7 @@ SVFileReader::readModel(const QXmlAttributes &attributes)
 
         if (refModel && alignedModel && pathModel) {
             AlignmentModel *model = new AlignmentModel
-                (refModel, alignedModel, 0, 0);
+                (refModel, alignedModel, nullptr);
             PathModel *pm = dynamic_cast<PathModel *>(pathModel);
             if (!pm) {
                 SVCERR << "WARNING: SV-XML: Model id " << path
@@ -739,7 +817,7 @@ bool
 SVFileReader::readView(const QXmlAttributes &attributes)
 {
     QString type = attributes.value("type");
-    m_currentPane = 0;
+    m_currentPane = nullptr;
     
     if (type != "pane") {
         SVCERR << "WARNING: SV-XML: Unexpected view type \""
@@ -749,7 +827,7 @@ SVFileReader::readView(const QXmlAttributes &attributes)
 
     m_currentPane = m_paneCallback.addPane();
 
-    SVCERR << "SVFileReader::addPane: pane is " << m_currentPane << endl;
+    SVDEBUG << "SVFileReader::addPane: pane is " << m_currentPane << endl;
 
     if (!m_currentPane) {
         SVCERR << "WARNING: SV-XML: Internal error: Failed to add pane!"
@@ -769,6 +847,14 @@ SVFileReader::readView(const QXmlAttributes &attributes)
     READ_MANDATORY(int, followZoom, toInt);
     QString tracking = attributes.value("tracking");
 
+    ZoomLevel zoomLevel;
+    int deepZoom = attributes.value("deepZoom").trimmed().toInt(&ok);
+    if (ok && zoom == 1 && deepZoom > 1) {
+        zoomLevel = { ZoomLevel::PixelsPerFrame, deepZoom };
+    } else {
+        zoomLevel = { ZoomLevel::FramesPerPixel, zoom };
+    }
+
     // Specify the follow modes before we set the actual values
     view->setFollowGlobalPan(followPan);
     view->setFollowGlobalZoom(followZoom);
@@ -779,7 +865,7 @@ SVFileReader::readView(const QXmlAttributes &attributes)
 
     // Then set these values
     view->setCentreFrame(centre);
-    view->setZoomLevel(zoom);
+    view->setZoomLevel(zoomLevel);
 
     // And pane properties
     READ_MANDATORY(int, centreLineVisible, toInt);
@@ -809,7 +895,7 @@ SVFileReader::readLayer(const QXmlAttributes &attributes)
         return false;
     }
 
-    Layer *layer = 0;
+    Layer *layer = nullptr;
     bool isNewLayer = false;
 
     // Layers are expected to be defined in layer elements in the data
@@ -891,7 +977,7 @@ SVFileReader::readLayer(const QXmlAttributes &attributes)
                     // Don't add a layer with an unknown model id
                     // unless it explicitly supports this state
                     m_document->deleteLayer(layer);
-                    m_layers[id] = layer = 0;
+                    m_layers[id] = layer = nullptr;
                     return false;
                 }
             }
@@ -920,7 +1006,7 @@ SVFileReader::readLayer(const QXmlAttributes &attributes)
     }
 
     m_currentLayer = layer;
-    m_inLayer = (layer != 0);
+    m_inLayer = (layer != nullptr);
 
     return true;
 }
@@ -940,7 +1026,7 @@ SVFileReader::readDatasetStart(const QXmlAttributes &attributes)
     
     int modelId = m_awaitingDatasets[id];
     
-    Model *model = 0;
+    Model *model = nullptr;
     if (haveModel(modelId)) {
         model = m_models[modelId];
     } else {
@@ -976,7 +1062,7 @@ SVFileReader::readDatasetStart(const QXmlAttributes &attributes)
 
     if (!good) {
         SVCERR << "WARNING: SV-XML: Model id " << modelId << " has wrong number of dimensions or inappropriate type for " << dimensions << "-D dataset " << id << endl;
-        m_currentDataset = 0;
+        m_currentDataset = nullptr;
         return false;
     }
 
@@ -1211,7 +1297,7 @@ SVFileReader::readDerivation(const QXmlAttributes &attributes)
         m_currentDerivedModel = m_models[modelId];
     } else {
         // we'll regenerate the model when the derivation element ends
-        m_currentDerivedModel = 0;
+        m_currentDerivedModel = nullptr;
     }
     
     m_currentDerivedModelId = modelId;
@@ -1290,7 +1376,7 @@ SVFileReader::readDerivation(const QXmlAttributes &attributes)
 bool
 SVFileReader::readPlayParameters(const QXmlAttributes &attributes)
 {
-    m_currentPlayParameters = 0;
+    m_currentPlayParameters = nullptr;
 
     int modelId = 0;
     bool modelOk = false;
@@ -1468,7 +1554,7 @@ public:
         m_inData(false),
         m_type(SVFileReader::UnknownFileType)
     { }
-    virtual ~SVFileIdentifier() { }
+    ~SVFileIdentifier() override { }
 
     void parse(QXmlInputSource &source) {
         QXmlSimpleReader reader;
@@ -1479,10 +1565,10 @@ public:
 
     SVFileReader::FileType getType() const { return m_type; }
 
-    virtual bool startElement(const QString &,
+    bool startElement(const QString &,
                               const QString &,
                               const QString &qName,
-                              const QXmlAttributes& atts)
+                              const QXmlAttributes& atts) override
     {
         QString name = qName.toLower();
 
@@ -1515,9 +1601,9 @@ public:
         return true;
     }
 
-    virtual bool endElement(const QString &,
+    bool endElement(const QString &,
                             const QString &,
-                            const QString &qName)
+                            const QString &qName) override
     {
         QString name = qName.toLower();
 
