@@ -13,8 +13,8 @@
     COPYING included with this distribution for more information.
 */
 
-#ifndef _SV_FILE_READER_H_
-#define _SV_FILE_READER_H_
+#ifndef SV_FILE_READER_H
+#define SV_FILE_READER_H
 
 #include "layer/LayerFactory.h"
 #include "transform/Transform.h"
@@ -181,19 +181,19 @@ public:
     // For loading a single layer onto an existing pane
     void setCurrentPane(Pane *pane) { m_currentPane = pane; }
     
-    virtual bool startElement(const QString &namespaceURI,
+    bool startElement(const QString &namespaceURI,
                               const QString &localName,
                               const QString &qName,
-                              const QXmlAttributes& atts);
+                              const QXmlAttributes& atts) override;
 
-    virtual bool characters(const QString &);
+    bool characters(const QString &) override;
 
-    virtual bool endElement(const QString &namespaceURI,
+    bool endElement(const QString &namespaceURI,
                             const QString &localName,
-                            const QString &qName);
+                            const QString &qName) override;
 
-    bool error(const QXmlParseException &exception);
-    bool fatalError(const QXmlParseException &exception);
+    bool error(const QXmlParseException &exception) override;
+    bool fatalError(const QXmlParseException &exception) override;
 
     enum FileType
     {
