@@ -20,11 +20,12 @@
 #include <QDir>
 #include <QUrl>
 #include <QCoreApplication>
+#include <QDateTime>
 
 #include <stdexcept>
 
-static SVDebug *svdebug = 0;
-static SVCerr *svcerr = 0;
+static SVDebug *svdebug = nullptr;
+static SVCerr *svcerr = nullptr;
 static QMutex mutex;
 
 SVDebug &getSVDebug() {
@@ -52,7 +53,7 @@ bool SVDebug::m_silenced = false;
 bool SVCerr::m_silenced = false;
 
 SVDebug::SVDebug() :
-    m_prefix(0),
+    m_prefix(nullptr),
     m_ok(false),
     m_eol(true)
 {
@@ -82,8 +83,9 @@ SVDebug::SVDebug() :
                              << "Failed to open debug log file "
                              << fileName << " for writing";
     } else {
-//        cerr << m_prefix << ": Log file is " << fileName << endl;
         m_ok = true;
+        (*this) << "Debug log started at "
+                << QDateTime::currentDateTime().toString() << endl;
     }
 }
 
