@@ -13,11 +13,15 @@
 */
 
 #include "AudioFileReaderTest.h"
+#include "BogusAudioFileReaderTest.h"
 #include "AudioFileWriterTest.h"
 #include "EncodingTest.h"
 #include "MIDIFileReaderTest.h"
+#include "CSVFormatTest.h"
 #include "CSVStreamWriterTest.h"
 
+#include "system/Init.h"
+
 #include <QtTest>
 
 #include <iostream>
@@ -26,6 +30,8 @@ int main(int argc, char *argv[])
 {
     int good = 0, bad = 0;
 
+    svSystemSpecificInitialisation();
+
     QString testDir;
 
 #ifdef Q_OS_WIN
@@ -34,19 +40,19 @@ int main(int argc, char *argv[])
     testDir = "../sonic-visualiser/svcore/data/fileio/test";
 #endif
 
-    if (argc > 1) {
-        SVCERR << "argc = " << argc << endl;
-        testDir = argv[1];
-    }
+    QCoreApplication app(argc, argv);
+    app.setOrganizationName("sonic-visualiser");
+    app.setApplicationName("test-svcore-data-fileio");
+
+    if (argc == 3 && string(argv[1]) == "--testdir") {
+        testDir = argv[2];
+        argc = 1;
+    }        
 
     if (testDir != "") {
         SVCERR << "Setting test directory base path to \"" << testDir << "\"" << endl;
     }
 
-    QCoreApplication app(argc, argv);
-    app.setOrganizationName("sonic-visualiser");
-    app.setApplicationName("test-fileio");
-
     {
         AudioFileReaderTest t(testDir);
         if (QTest::qExec(&t, argc, argv) == 0) ++good;
@@ -59,6 +65,12 @@ int main(int argc, char *argv[])
         else ++bad;
     }
 
+    {
+        BogusAudioFileReaderTest t;
+        if (QTest::qExec(&t, argc, argv) == 0) ++good;
+        else ++bad;
+    }
+
     {
         EncodingTest t(testDir);
         if (QTest::qExec(&t, argc, argv) == 0) ++good;
@@ -71,6 +83,12 @@ int main(int argc, char *argv[])
         else ++bad;
     }
 
+    {
+        CSVFormatTest t(testDir);
+        if (QTest::qExec(&t, argc, argv) == 0) ++good;
+        else ++bad;
+    }
+
     {
         CSVStreamWriterTest t;
         if (QTest::qExec(&t, argc, argv) == 0) ++good;
@@ -78,10 +96,10 @@ int main(int argc, char *argv[])
     }
 
     if (bad > 0) {
-    SVCERR << "\n********* " << bad << " test suite(s) failed!\n" << endl;
+        SVCERR << "\n********* " << bad << " test suite(s) failed!\n" << endl;
         return 1;
     } else {
-    SVCERR << "All tests passed" << endl;
+        SVCERR << "All tests passed" << endl;
         return 0;
     }
 }
