@@ -21,14 +21,12 @@
 
 AlignmentModel::AlignmentModel(Model *reference,
                                Model *aligned,
-                               Model *inputModel,
                                SparseTimeValueModel *path) :
     m_reference(reference),
     m_aligned(aligned),
-    m_inputModel(inputModel),
     m_rawPath(path),
-    m_path(0),
-    m_reversePath(0),
+    m_path(nullptr),
+    m_reversePath(nullptr),
     m_pathBegun(false),
     m_pathComplete(false)
 {
@@ -54,9 +52,6 @@ AlignmentModel::AlignmentModel(Model *reference,
 
 AlignmentModel::~AlignmentModel()
 {
-    if (m_inputModel) m_inputModel->aboutToDelete();
-    delete m_inputModel;
-
     if (m_rawPath) m_rawPath->aboutToDelete();
     delete m_rawPath;
 
@@ -129,7 +124,7 @@ AlignmentModel::isReady(int *completion) const
 const ZoomConstraint *
 AlignmentModel::getZoomConstraint() const
 {
-    return 0;
+    return nullptr;
 }
 
 const Model *
@@ -177,7 +172,7 @@ AlignmentModel::pathChanged()
         cerr << "AlignmentModel: deleting raw path model" << endl;
         if (m_rawPath) m_rawPath->aboutToDelete();
         delete m_rawPath;
-        m_rawPath = 0;
+        m_rawPath = nullptr;
     }
 }
 
@@ -212,9 +207,6 @@ AlignmentModel::pathCompletionChanged()
             constructPath();
             constructReversePath();
             
-            if (m_inputModel) m_inputModel->aboutToDelete();
-            delete m_inputModel;
-            m_inputModel = 0;
         }
     }
 
