@@ -52,10 +52,10 @@ Layer::connectSignals(const Model *model)
             this, SIGNAL(modelChanged()));
 
     connect(model, SIGNAL(modelChangedWithin(sv_frame_t, sv_frame_t)),
-	    this, SIGNAL(modelChangedWithin(sv_frame_t, sv_frame_t)));
+            this, SIGNAL(modelChangedWithin(sv_frame_t, sv_frame_t)));
 
     connect(model, SIGNAL(completionChanged()),
-	    this, SIGNAL(modelCompletionChanged()));
+            this, SIGNAL(modelCompletionChanged()));
 
     connect(model, SIGNAL(alignmentCompletionChanged()),
             this, SIGNAL(modelAlignmentCompletionChanged()));
@@ -65,7 +65,7 @@ QString
 Layer::getPropertyContainerIconName() const
 {
     return LayerFactory::getInstance()->getLayerIconName
-	(LayerFactory::getInstance()->getLayerType(this));
+        (LayerFactory::getInstance()->getLayerType(this));
 }
 
 void
@@ -85,14 +85,14 @@ Layer::getLayerPresentationName() const
 
     QString modelName;
     if (getModel()) modelName = getModel()->objectName();
-	    
+            
     QString text;
     if (modelName != "") {
-	text = QString("%1: %2").arg(modelName).arg(layerName);
+        text = QString("%1: %2").arg(modelName).arg(layerName);
     } else {
-	text = layerName;
+        text = layerName;
     }
-	
+        
     return text;
 }
 
@@ -109,9 +109,9 @@ Layer::getPlayParameters()
 //    cerr << "Layer (" << this << ", " << objectName() << ")::getPlayParameters: model is "<< getModel() << endl;
     const Model *model = getModel();
     if (model) {
-	return PlayParameterRepository::getInstance()->getPlayParameters(model);
+        return PlayParameterRepository::getInstance()->getPlayParameters(model);
     }
-    return 0;
+    return nullptr;
 }
 
 void
@@ -169,7 +169,7 @@ sv_frame_t
 Layer::alignToReference(LayerGeometryProvider *v, sv_frame_t frame) const
 {
     const Model *m = getModel();
-    SVDEBUG << "Layer::alignToReference(" << frame << "): model = " << m << ", alignment reference = " << (m ? m->getAlignmentReference() : 0) << endl;
+    SVDEBUG << "Layer::alignToReference(" << frame << "): model = " << m << ", alignment reference = " << (m ? m->getAlignmentReference() : nullptr) << endl;
     if (m && m->getAlignmentReference()) {
         return m->alignToReference(frame);
     } else {
@@ -181,7 +181,7 @@ sv_frame_t
 Layer::alignFromReference(LayerGeometryProvider *v, sv_frame_t frame) const
 {
     const Model *m = getModel();
-    SVDEBUG << "Layer::alignFromReference(" << frame << "): model = " << m << ", alignment reference = " << (m ? m->getAlignmentReference() : 0) << endl;
+    SVDEBUG << "Layer::alignFromReference(" << frame << "): model = " << m << ", alignment reference = " << (m ? m->getAlignmentReference() : nullptr) << endl;
     if (m && m->getAlignmentReference()) {
         return m->alignFromReference(frame);
     } else {
@@ -373,8 +373,24 @@ Layer::DeleteMeasurementRectCommand::unexecute()
 void
 Layer::measureStart(LayerGeometryProvider *v, QMouseEvent *e)
 {
-    setMeasureRectFromPixrect(v, m_draggingRect,
-                              QRect(e->x(), e->y(), 0, 0));
+    m_draggingRect.haveFrames = hasTimeXAxis();
+
+    // NB if haveFrames, then pixrect x and width will be rewritten on
+    // every paint according to the current locations of the
+    // definitive frame values. So we should set the start frame value
+    // once on measureStart, and then not modify it on drag (to avoid
+    // drift from repeated conversion back and forth).
+    
+    m_draggingRect.pixrect = QRect(e->x(), e->y(), 0, 0);
+
+    if (m_draggingRect.haveFrames) {
+        m_draggingRect.startFrame = v->getFrameForX(e->x());
+        m_draggingRect.endFrame = v->getFrameForX(e->x());
+    }
+
+    setMeasureRectYCoord(v, m_draggingRect, true, e->y());
+    setMeasureRectYCoord(v, m_draggingRect, false, e->y());
+
     m_haveDraggingRect = true;
 }
 
@@ -383,11 +399,15 @@ Layer::measureDrag(LayerGeometryProvider *v, QMouseEvent *e)
 {
     if (!m_haveDraggingRect) return;
 
-    setMeasureRectFromPixrect(v, m_draggingRect,
-                              QRect(m_draggingRect.pixrect.x(),
-                                    m_draggingRect.pixrect.y(),
-                                    e->x() - m_draggingRect.pixrect.x(),
-                                    e->y() - m_draggingRect.pixrect.y()));
+    m_draggingRect.pixrect.setHeight(e->y() - m_draggingRect.pixrect.y());
+
+    if (m_draggingRect.haveFrames) {
+        m_draggingRect.endFrame = v->getFrameForX(e->x());
+    } else {
+        m_draggingRect.pixrect.setWidth(e->x() - m_draggingRect.pixrect.x());
+    }
+
+    setMeasureRectYCoord(v, m_draggingRect, false, e->y());
 }
 
 void
@@ -588,6 +608,31 @@ Layer::paintMeasurementRect(LayerGeometryProvider *v, QPainter &paint,
     v->drawMeasurementRect(paint, this, r.pixrect.normalized(), focus);
 }
 
+bool
+Layer::valueExtentsMatchMine(LayerGeometryProvider *v) const
+{
+    double min, min_;
+    double max, max_;
+    bool logarithmic, logarithmic_;
+    QString unit;
+
+    if (!getValueExtents(min_, max_, logarithmic_, unit)) {
+        return false;
+    }
+
+    if (!v->getValueExtents(unit, min, max, logarithmic)) {
+        return false;
+    }
+
+    if (min != min_ ||
+        max != max_ ||
+        logarithmic != logarithmic_) {
+        return false;
+    }
+
+    return true;
+}
+
 void
 Layer::toXml(QTextStream &stream,
              QString indent, QString extraAttributes) const
@@ -600,12 +645,12 @@ Layer::toXml(QTextStream &stream,
     }
 
     stream << QString("<layer id=\"%2\" type=\"%1\" name=\"%3\" model=\"%4\" %5")
-	.arg(encodeEntities(LayerFactory::getInstance()->getLayerTypeName
+        .arg(encodeEntities(LayerFactory::getInstance()->getLayerTypeName
                             (LayerFactory::getInstance()->getLayerType(this))))
-	.arg(getObjectExportId(this))
-	.arg(encodeEntities(objectName()))
-	.arg(getObjectExportId(getModel()))
-	.arg(extraAttributes);
+        .arg(getObjectExportId(this))
+        .arg(encodeEntities(objectName()))
+        .arg(getObjectExportId(getModel()))
+        .arg(extraAttributes);
 
     if (m_measureRects.empty()) {
         stream << QString("/>\n");
@@ -634,11 +679,11 @@ Layer::toBriefXml(QTextStream &stream,
     }
 
     stream << QString("<layer id=\"%2\" type=\"%1\" name=\"%3\" model=\"%4\" %5/>\n")
-	.arg(encodeEntities(LayerFactory::getInstance()->getLayerTypeName
+        .arg(encodeEntities(LayerFactory::getInstance()->getLayerTypeName
                             (LayerFactory::getInstance()->getLayerType(this))))
-	.arg(getObjectExportId(this))
-	.arg(encodeEntities(objectName()))
-	.arg(getObjectExportId(getModel()))
+        .arg(getObjectExportId(this))
+        .arg(encodeEntities(objectName()))
+        .arg(getObjectExportId(getModel()))
         .arg(extraAttributes);
 }
 
