@@ -56,11 +56,12 @@
 using namespace std;
 
 SpectrogramLayer::SpectrogramLayer(Configuration config) :
-    m_model(0),
+    m_model(nullptr),
     m_channel(0),
     m_windowSize(1024),
     m_windowType(HanningWindow),
     m_windowHopLevel(2),
+    m_oversampling(1),
     m_gain(1.0),
     m_initialGain(1.0),
     m_threshold(1.0e-8f),
@@ -73,6 +74,7 @@ SpectrogramLayer::SpectrogramLayer(Configuration config) :
     m_colourScale(ColourScaleType::Log),
     m_colourScaleMultiple(1.0),
     m_colourMap(0),
+    m_colourInverted(false),
     m_binScale(BinScale::Linear),
     m_binDisplay(BinDisplay::AllBins),
     m_normalization(ColumnNormalization::None),
@@ -81,9 +83,9 @@ SpectrogramLayer::SpectrogramLayer(Configuration config) :
     m_synchronous(false),
     m_haveDetailedScale(false),
     m_exiting(false),
-    m_fftModel(0),
-    m_wholeCache(0),
-    m_peakCache(0),
+    m_fftModel(nullptr),
+    m_wholeCache(nullptr),
+    m_peakCache(nullptr),
     m_peakCacheDivisor(8)
 {
     QString colourConfigName = "spectrogram-colour";
@@ -146,9 +148,9 @@ SpectrogramLayer::deleteDerivedModels()
     delete m_peakCache;
     delete m_wholeCache;
 
-    m_fftModel = 0;
-    m_peakCache = 0;
-    m_wholeCache = 0;
+    m_fftModel = nullptr;
+    m_peakCache = nullptr;
+    m_wholeCache = nullptr;
 }
 
 pair<ColourScaleType, double>
@@ -235,6 +237,7 @@ SpectrogramLayer::getProperties() const
     list.push_back("Colour Scale");
     list.push_back("Window Size");
     list.push_back("Window Increment");
+    list.push_back("Oversampling");
     list.push_back("Normalization");
     list.push_back("Bin Display");
     list.push_back("Threshold");
@@ -253,6 +256,7 @@ SpectrogramLayer::getPropertyLabel(const PropertyName &name) const
     if (name == "Colour Scale") return tr("Colour Scale");
     if (name == "Window Size") return tr("Window Size");
     if (name == "Window Increment") return tr("Window Overlap");
+    if (name == "Oversampling") return tr("Oversampling");
     if (name == "Normalization") return tr("Normalization");
     if (name == "Bin Display") return tr("Bin Display");
     if (name == "Threshold") return tr("Threshold");
@@ -286,7 +290,8 @@ SpectrogramLayer::getPropertyGroupName(const PropertyName &name) const
     if (name == "Bin Display" ||
         name == "Frequency Scale") return tr("Bins");
     if (name == "Window Size" ||
-        name == "Window Increment") return tr("Window");
+        name == "Window Increment" ||
+        name == "Oversampling") return tr("Window");
     if (name == "Colour" ||
         name == "Threshold" ||
         name == "Colour Rotation") return tr("Colour");
@@ -375,7 +380,17 @@ SpectrogramLayer::getPropertyRangeAndValue(const PropertyName &name,
         *deflt = 2;
 
         val = m_windowHopLevel;
-    
+
+    } else if (name == "Oversampling") {
+
+        *min = 0;
+        *max = 3;
+        *deflt = 0;
+
+        val = 0;
+        int ov = m_oversampling;
+        while (ov > 1) { ov >>= 1; val ++; }
+        
     } else if (name == "Min Frequency") {
 
         *min = 0;
@@ -448,7 +463,7 @@ SpectrogramLayer::getPropertyValueLabel(const PropertyName &name,
                                         int value) const
 {
     if (name == "Colour") {
-        return ColourMapper::getColourMapName(value);
+        return ColourMapper::getColourMapLabel(value);
     }
     if (name == "Colour Scale") {
         switch (value) {
@@ -484,6 +499,15 @@ SpectrogramLayer::getPropertyValueLabel(const PropertyName &name,
         case 5: return tr("93.75 %");
         }
     }
+    if (name == "Oversampling") {
+        switch (value) {
+        default:
+        case 0: return tr("1x");
+        case 1: return tr("2x");
+        case 2: return tr("4x");
+        case 3: return tr("8x");
+        }
+    }
     if (name == "Min Frequency") {
         switch (value) {
         default:
@@ -558,7 +582,7 @@ SpectrogramLayer::getNewPropertyRangeMapper(const PropertyName &name) const
         return new LinearRangeMapper(-81, -1, -81, -1, tr("dB"), false,
                                      { { -81, Strings::minus_infinity } });
     }
-    return 0;
+    return nullptr;
 }
 
 void
@@ -577,6 +601,8 @@ SpectrogramLayer::setProperty(const PropertyName &name, int value)
         setWindowSize(32 << value);
     } else if (name == "Window Increment") {
         setWindowHopLevel(value);
+    } else if (name == "Oversampling") {
+        setOversampling(1 << value);
     } else if (name == "Min Frequency") {
         switch (value) {
         default:
@@ -672,7 +698,6 @@ SpectrogramLayer::preferenceChanged(PropertyContainer::PropertyName name)
         return;
     }
     if (name == "Spectrogram Y Smoothing") {
-        setWindowSize(m_windowSize);
         invalidateRenderers();
         invalidateMagnitudes();
         emit layerParametersChanged();
@@ -705,41 +730,19 @@ SpectrogramLayer::getChannel() const
     return m_channel;
 }
 
-int
-SpectrogramLayer::getFFTOversampling() const
-{
-    if (m_binDisplay != BinDisplay::AllBins) {
-        return 1;
-    }
-
-    Preferences::SpectrogramSmoothing smoothing = 
-        Preferences::getInstance()->getSpectrogramSmoothing();
-    
-    if (smoothing == Preferences::NoSpectrogramSmoothing ||
-        smoothing == Preferences::SpectrogramInterpolated) {
-        return 1;
-    }
-
-    return 4;
-}
-
 int
 SpectrogramLayer::getFFTSize() const
 {
-    return m_windowSize * getFFTOversampling();
+    return m_windowSize * m_oversampling;
 }
 
 void
 SpectrogramLayer::setWindowSize(int ws)
 {
     if (m_windowSize == ws) return;
-
     invalidateRenderers();
-    
     m_windowSize = ws;
-    
     recreateFFTModel();
-
     emit layerParametersChanged();
 }
 
@@ -753,13 +756,9 @@ void
 SpectrogramLayer::setWindowHopLevel(int v)
 {
     if (m_windowHopLevel == v) return;
-
     invalidateRenderers();
-    
     m_windowHopLevel = v;
-    
     recreateFFTModel();
-
     emit layerParametersChanged();
 }
 
@@ -769,6 +768,22 @@ SpectrogramLayer::getWindowHopLevel() const
     return m_windowHopLevel;
 }
 
+void
+SpectrogramLayer::setOversampling(int oversampling)
+{
+    if (m_oversampling == oversampling) return;
+    invalidateRenderers();
+    m_oversampling = oversampling;
+    recreateFFTModel();
+    emit layerParametersChanged();
+}
+
+int
+SpectrogramLayer::getOversampling() const
+{
+    return m_oversampling;
+}
+
 void
 SpectrogramLayer::setWindowType(WindowType w)
 {
@@ -1041,6 +1056,9 @@ SpectrogramLayer::setLayerDormant(const LayerGeometryProvider *v, bool dormant)
 bool
 SpectrogramLayer::isLayerScrollable(const LayerGeometryProvider *) const
 {
+    // we do our own cacheing, and don't want to be responsible for
+    // guaranteeing to get an invisible seam if someone else scrolls
+    // us and we just fill in
     return false;
 }
 
@@ -1081,7 +1099,8 @@ SpectrogramLayer::cacheInvalid(
 bool
 SpectrogramLayer::hasLightBackground() const 
 {
-    return ColourMapper(m_colourMap, 1.f, 255.f).hasLightBackground();
+    return ColourMapper(m_colourMap, m_colourInverted, 1.f, 255.f)
+        .hasLightBackground();
 }
 
 double
@@ -1356,7 +1375,7 @@ SpectrogramLayer::recreateFFTModel()
     SVDEBUG << "SpectrogramLayer::recreateFFTModel called" << endl;
 
     if (!m_model || !m_model->isOK()) {
-        emit sliceableModelReplaced(m_fftModel, 0);
+        emit sliceableModelReplaced(m_fftModel, nullptr);
         deleteDerivedModels();
         return;
     }
@@ -1365,11 +1384,11 @@ SpectrogramLayer::recreateFFTModel()
     
     if (m_peakCache) m_peakCache->aboutToDelete();
     delete m_peakCache;
-    m_peakCache = 0;
+    m_peakCache = nullptr;
 
     if (m_wholeCache) m_wholeCache->aboutToDelete();
     delete m_wholeCache;
-    m_wholeCache = 0;
+    m_wholeCache = nullptr;
     
     FFTModel *newModel = new FFTModel(m_model,
                                       m_channel,
@@ -1380,12 +1399,12 @@ SpectrogramLayer::recreateFFTModel()
 
     if (!newModel->isOK()) {
         QMessageBox::critical
-            (0, tr("FFT cache failed"),
+            (nullptr, tr("FFT cache failed"),
              tr("Failed to create the FFT model for this spectrogram.\n"
                 "There may be insufficient memory or disc space to continue."));
         delete newModel;
         delete m_fftModel;
-        m_fftModel = 0;
+        m_fftModel = nullptr;
         return;
     }
 
@@ -1518,19 +1537,19 @@ SpectrogramLayer::getRenderer(LayerGeometryProvider *v) const
 
         if (m_colourScale != ColourScaleType::Phase &&
             m_normalization != ColumnNormalization::Hybrid) {
-            params.scaleFactor *= 2.f / float(getFFTSize());
+            params.scaleFactor *= 2.f / float(getWindowSize());
         }
 
         Preferences::SpectrogramSmoothing smoothing = 
             Preferences::getInstance()->getSpectrogramSmoothing();
         params.interpolate = 
-            (smoothing == Preferences::SpectrogramInterpolated ||
-             smoothing == Preferences::SpectrogramZeroPaddedAndInterpolated);
+            (smoothing != Preferences::NoSpectrogramSmoothing);
 
         m_renderers[viewId] = new Colour3DPlotRenderer(sources, params);
 
         m_crosshairColour =
-            ColourMapper(m_colourMap, 1.f, 255.f).getContrastingColour();
+            ColourMapper(m_colourMap, m_colourInverted, 1.f, 255.f)
+            .getContrastingColour();
     }
 
     return m_renderers[viewId];
@@ -2298,9 +2317,9 @@ public:
     SpectrogramRangeMapper(sv_samplerate_t sr, int /* fftsize */) :
         m_dist(sr / 2),
         m_s2(sqrt(sqrt(2))) { }
-    ~SpectrogramRangeMapper() { }
+    ~SpectrogramRangeMapper() override { }
     
-    virtual int getPositionForValue(double value) const {
+    int getPositionForValue(double value) const override {
 
         double dist = m_dist;
     
@@ -2314,12 +2333,12 @@ public:
         return n;
     }
     
-    virtual int getPositionForValueUnclamped(double value) const {
+    int getPositionForValueUnclamped(double value) const override {
         // We don't really support this
         return getPositionForValue(value);
     }
 
-    virtual double getValueForPosition(int position) const {
+    double getValueForPosition(int position) const override {
 
         // Vertical zoom step 0 shows the entire range from DC ->
         // Nyquist frequency.  Step 1 shows 2^(1/4) of the range of
@@ -2337,12 +2356,12 @@ public:
         return dist;
     }
     
-    virtual double getValueForPositionUnclamped(int position) const {
+    double getValueForPositionUnclamped(int position) const override {
         // We don't really support this
         return getValueForPosition(position);
     }
 
-    virtual QString getUnit() const { return "Hz"; }
+    QString getUnit() const override { return "Hz"; }
 
 protected:
     double m_dist;
@@ -2457,7 +2476,7 @@ SpectrogramLayer::setVerticalZoomStep(int step)
 RangeMapper *
 SpectrogramLayer::getNewVerticalZoomRangeMapper() const
 {
-    if (!m_model) return 0;
+    if (!m_model) return nullptr;
     return new SpectrogramRangeMapper(m_model->getSampleRate(), getFFTSize());
 }
 
@@ -2497,29 +2516,40 @@ SpectrogramLayer::toXml(QTextStream &stream,
     s += QString("channel=\"%1\" "
                  "windowSize=\"%2\" "
                  "windowHopLevel=\"%3\" "
-                 "gain=\"%4\" "
-                 "threshold=\"%5\" ")
+                 "oversampling=\"%4\" "
+                 "gain=\"%5\" "
+                 "threshold=\"%6\" ")
         .arg(m_channel)
         .arg(m_windowSize)
         .arg(m_windowHopLevel)
+        .arg(m_oversampling)
         .arg(m_gain)
         .arg(m_threshold);
 
     s += QString("minFrequency=\"%1\" "
                  "maxFrequency=\"%2\" "
                  "colourScale=\"%3\" "
-                 "colourScheme=\"%4\" "
-                 "colourRotation=\"%5\" "
-                 "frequencyScale=\"%6\" "
-                 "binDisplay=\"%7\" ")
+                 "colourRotation=\"%4\" "
+                 "frequencyScale=\"%5\" "
+                 "binDisplay=\"%6\" ")
         .arg(m_minFrequency)
         .arg(m_maxFrequency)
         .arg(convertFromColourScale(m_colourScale, m_colourScaleMultiple))
-        .arg(m_colourMap)
         .arg(m_colourRotation)
         .arg(int(m_binScale))
         .arg(int(m_binDisplay));
 
+    // New-style colour map attribute, by string id rather than by
+    // number
+
+    s += QString("colourMap=\"%1\" ")
+        .arg(ColourMapper::getColourMapId(m_colourMap));
+
+    // Old-style colour map attribute
+
+    s += QString("colourScheme=\"%1\" ")
+        .arg(ColourMapper::getBackwardCompatibilityColourMap(m_colourMap));
+    
     // New-style normalization attributes, allowing for more types of
     // normalization in future: write out the column normalization
     // type separately, and then whether we are normalizing visible
@@ -2571,6 +2601,9 @@ SpectrogramLayer::setProperties(const QXmlAttributes &attributes)
         }
     }
 
+    int oversampling = attributes.value("oversampling").toUInt(&ok);
+    if (ok) setOversampling(oversampling);
+
     float gain = attributes.value("gain").toFloat(&ok);
     if (ok) setGain(gain);
 
@@ -2596,8 +2629,16 @@ SpectrogramLayer::setProperties(const QXmlAttributes &attributes)
         setColourScaleMultiple(colourScale.second);
     }
 
-    int colourMap = attributes.value("colourScheme").toInt(&ok);
-    if (ok) setColourMap(colourMap);
+    QString colourMapId = attributes.value("colourMap");
+    int colourMap = ColourMapper::getColourMapById(colourMapId);
+    if (colourMap >= 0) {
+        setColourMap(colourMap);
+    } else {
+        colourMap = attributes.value("colourScheme").toInt(&ok);
+        if (ok && colourMap < ColourMapper::getColourMapCount()) {
+            setColourMap(colourMap);
+        }
+    }
 
     int colourRotation = attributes.value("colourRotation").toInt(&ok);
     if (ok) setColourRotation(colourRotation);
