@@ -41,7 +41,7 @@ using std::vector;
 
 WaveformLayer::WaveformLayer() :
     SingleColourLayer(),
-    m_model(0),
+    m_model(nullptr),
     m_gain(1.0f),
     m_autoNormalize(false),
     m_showMeans(true),
@@ -50,7 +50,7 @@ WaveformLayer::WaveformLayer() :
     m_scale(LinearScale),
     m_middleLineHeight(0.5),
     m_aggressive(false),
-    m_cache(0),
+    m_cache(nullptr),
     m_cacheValid(false)
 {
 }
@@ -218,7 +218,7 @@ WaveformLayer::getNewPropertyRangeMapper(const PropertyName &name) const
     if (name == "Gain") {
         return new LinearRangeMapper(-50, 50, -25, 25, tr("dB"));
     }
-    return 0;
+    return nullptr;
 }
 
 void
@@ -919,9 +919,9 @@ WaveformLayer::paintChannel(LayerGeometryProvider *v,
 
         case MeterScale:
             if (!mergingChannels) {
-                double r0 = fabs(AudioLevel::multiplier_to_preview
+                double r0 = std::abs(AudioLevel::multiplier_to_preview
                                  (range.min() * gain, m));
-                double r1 = fabs(AudioLevel::multiplier_to_preview
+                double r1 = std::abs(AudioLevel::multiplier_to_preview
                                  (range.max() * gain, m));
                 rangeTop = std::max(r0, r1);
                 meanTop = std::min(r0, r1);
@@ -1029,6 +1029,9 @@ WaveformLayer::paintChannel(LayerGeometryProvider *v,
     }
 
     double penWidth = 1.0;
+    if (v->getZoomLevel().zone == ZoomLevel::FramesPerPixel) {
+        penWidth = 0.0;
+    }
     
     if (m_model->isReady()) {
         paint->setPen(QPen(baseColour, penWidth));
